checkRequire("Lua_GuideItem");
checkRequire("Lua_GuideArrow");
checkRequire("Lua_ZhiYinOneData");
Lua_GuideWindow =  class("Lua_GuideWindow", Lua_Window);
function Lua_GuideWindow:ctor()
	self:superCall("ctor");

	self.windowName = "Lua_GuideWindow";
	self.layer = 6000;
	self.showClose = false;
end

function Lua_GuideWindow:buildShowItem()
	self:superCall("buildShowItem");

	self.maskBg:setAltas("common_atlas_1", "black_70%");

	self.curStep = 1;
	self.needSetAutoNext = true;

	local half_w = MainWinDefine.V_width / 2;
	local half_h = MainWinDefine.V_height / 2;
	self.skipBg = UICreate.createUIAtlasImage(self.content, "zhiyin_atlas", "ui_point_btn_01", 0, 0, 0, 0);
	self.skipBg.name = "skipBg";
	self.skipBg:setLocation(half_w - 73 - 14, half_h - 50, 0);
	self.skipBg:setDepth(10);

	self.skipIcon = UICreate.createUIAtlasImage(self.content, "zhiyin_atlas", "ui_point_z_01", 0, 0, 0, 0);
	self.skipIcon.name = "skipIcon";
	self.skipIcon:setLocation(half_w - 73, half_h - 50, 0);
	self.skipIcon:setDepth(11);
	self.skipIcon:addClickFuntion(self, self.hide);

	self.mouseBtn = UICreate.createUIAtlasImage(self.content, "common_atlas_1", "ui_common_black_50", 0, 0, 100, 100);
	self.mouseBtn.name = "mouseBtn";
	self.mouseBtn:setDepth(-2);
	self.mouseBtn:addClickFuntion(self, self.onMaskObjClick);

	self.masObj = UICreate.createMask(self.content, 0, 0, 10, 10, 0);
	self.masObj.name = "masObj";
	self.masObj:SetRenderQueue(self.mouseBtn, -8);

	self.tipItem = Lua_GuideItem.new(self.content);
	self.tipItem:setDir(2);
	
	self.arrowItem = Lua_GuideArrow.new(self.content);

	self:addTimer("guide", 0.1, self, self.onEnterFrame);
	self.autoTime = Lua_CommonUtil.getCommonConfig("guide_auto_time", 1);
end

function Lua_GuideWindow:showWin(param)
	-- print("Lua_GuideWindow:showWin");
	Lua_WindowUtil.hideOtherWindow();
	DataCenter.roleData.curGuide = param;
	self.curStep = 1;

	self.curZhiYinData = Lua_ZhiYinOneData.new(param);
	if self.curZhiYinData.hideSkip == true then 
		self.skipIcon:setEnable(false);
		self.skipBg:setEnable(false);
	else
		self.skipIcon:setEnable(true);
		self.skipBg:setEnable(true);
	end

	self:checkStep();

	if self.curZhiYinData.stopPlayer == 1 then
		DataCenter.guideData.stopMoveToGuide = true;
		DataCenter.hook:stop(true);

		local rolePlayer = ThingUtil.instance:getThingById(DataCenter.roleData.roleId);
		if rolePlayer ~= nil then
			rolePlayer.fightControl:cancelFight();
			rolePlayer:stopMove(true, true);
		end
	end
end

function Lua_GuideWindow:onEnterFrame()
	if self.curZhiYinData == nil then
		return;
	end

	local stepData = self.curZhiYinData:getStep(self.curStep);
	if stepData ~= nil and stepData.type == 3 then
		self:initPointData();
	end
end

function Lua_GuideWindow:checkStep()
	if self.curZhiYinData == nil then
		self:hide();
		return;
	end

	local stepData = self.curZhiYinData:getStep(self.curStep);
	if stepData == nil then
		self:hide();
		return;
	end

	if stepData.outTeam == 1 then
		DataCenter.teamData:quitTeam();
	end

	if stepData.type == 1 then -- 切换主界面状态
		self:setGuiItemState(false);
		self.curStep = self.curStep + 1;
		Lua_MsgUtil.callFunc("SET_MAIN_MENU", stepData.menu);
		self:checkStep();
	elseif stepData.type == 2 then -- 打开某个界面
		self:setGuiItemState(false);
		self.curStep = self.curStep + 1;
		Lua_WindowUtil.openWin(stepData.winName, WinParam.ACTION_OPEN, stepData.data);
		self:checkStep();
	elseif stepData.type == 4 then -- 展开、收齐右上角图标
		self:setGuiItemState(false);
		if stepData.showIcon == 1 then -- 展开
			DataCenter.allRtData:setSystemState(true);
			DataCenter.allRtData:setPlayerState(true);
		else -- 收起来
			DataCenter.allRtData:setPlayerState(false);
		end
		Lua_MsgUtil.callFunc("TORRIGHT_UPDATE");
		self.curStep = self.curStep + 1;
		self:checkStep();
	elseif stepData.type == 5 then -- 指引自动跑主线任务
		local truckTaskList = DataCenter.taskData:getListByType(Lua_TaskDefine.TRUCK);
		if truckTaskList:getSize() > 0 then
			truckTaskList[1]:exeTask();
			-- DataCenter.hook:doTruckTask();
		end
		self.curStep = self.curStep + 1;
		self:checkStep();
	else -- 点击指向
		self:initPointData();
	end
end

function Lua_GuideWindow:initPointData()
	local stepData = self.curZhiYinData:getStep(self.curStep);
	local sizeStr = LuaUtil.getUIItemSize(stepData.clickObj);

	local arr = string.split(sizeStr, "|");
	local w = tonumber(arr[1]);
	local h = tonumber(arr[2]);
	local px = tonumber(arr[3]);
	local py = tonumber(arr[4]);
	local pz = 0;
	-- print("stepData.clickObj ", stepData.clickObj, w, h);
	local offset_x = stepData.offset_x == nil and 0 or stepData.offset_x;
	local offset_y = stepData.offset_y == nil and 0 or stepData.offset_y;
	local offset_width = stepData.offset_width == nil and 0 or stepData.offset_width;
	local offset_height = stepData.offset_height == nil and 0 or stepData.offset_height;
	if w == 0 or h == 0 then
		self:setGuiItemState(false);
		self.masObj:SetDimensions(10, 10);
		self.mouseBtn:SetDimensions(100, 100);
	else
		self:setGuiItemState(true);
		self.masObj:SetDimensions(w * 0.1 + offset_width * 0.1, h * 0.1 + offset_height * 0.1);
		self.mouseBtn:SetDimensions(w + offset_width, h + offset_height);
	end
	self.masObj:setLocation(px + offset_x, py + offset_y,pz);
	self.mouseBtn:setLocation(px + offset_x, py + offset_y,pz);

	if stepData.info ~= nil then
		self.tipItem:setLocation(stepData.info_x, stepData.info_y);
		self.tipItem:setDir(stepData.dir);
		self.tipItem:setData(stepData.info);
		self.tipItem:setEnable(true);
	else
		self.tipItem:setEnable(false);
	end
	
	if stepData.arrow ~= nil then
		self:setBtnEffect(stepData.btn_effect, px, py);
		self.arrowItem:setEnable(true);
		self.arrowItem:setArrowDir(stepData.arrow);
		self.arrowItem:setArrowRenderQ(self.mouseBtn, 8);
		local arrowX = px;
		local arrowY = py;
		local arrowOffSet = 45;
		if stepData.arrow == 1 then
			arrowY = arrowY- h / 2 - arrowOffSet;
		elseif stepData.arrow == 2 then
			arrowX = arrowX - w / 2 - arrowOffSet;
		elseif stepData.arrow == 3 then
			arrowY = arrowY + h / 2 + arrowOffSet;
		elseif stepData.arrow == 4 then
			arrowX = arrowX + w / 2 + arrowOffSet;
		end
		self.arrowItem:setLocation(arrowX,arrowY,pz);
	else
		self.arrowItem:setEnable(false);
	end

	if self.needSetAutoNext == true then
		self.needSetAutoNext = false;
		self:addTimer("onMaskObjClick", self.autoTime, self, self.onMaskObjClick);
	end
end

function Lua_GuideWindow:setBtnEffect(effectName,px,py)
	if effectName ~= nil then
		if self.btnEffect == nil then
			self.btnEffect = UICreate.createUIEffect(self.content, nil, nil, 0, 0);
		end
		self.btnEffect:setLocation(px, py, -2501);

		if self.effectName ~= effectName then
			self.effectName = effectName;
			self.btnEffect:setUrl("/effects/scsEffects/"..effectName,effectName);
		end
	else
		if self.btnEffect ~= nil then
			self.btnEffect:dispose();
			self.btnEffect = nil;
		end
	end
end

function Lua_GuideWindow:setGuiItemState(val)
	self.masObj:setEnable(val);
	self.mouseBtn:setEnable(val);
	self.tipItem:setEnable(val);
end

function Lua_GuideWindow:onMaskClick(go)
	self:onMaskObjClick();
end

function Lua_GuideWindow:onMaskObjClick(go)
	-- print("onMaskObjClick");
	Lua_CommonUtil.removeTimer(self, self.onMaskObjClick);
	
	local stepData = self.curZhiYinData:getStep(self.curStep);
	LuaUtil.callUIItemClick(stepData.clickObj);
	self.curStep = self.curStep + 1;
	self.needSetAutoNext = true;
	self:checkStep();
end

function Lua_GuideWindow:hide()
	self:superCall("hide");

	DataCenter.guideData:doContinueTruck();
end

function Lua_GuideWindow:dispose()
	Lua_CommonUtil.removeTimer(self, self.onMaskObjClick);
	DataCenter.roleData.curGuide = 0;
	self.masObj:dispose();

	self:superCall("dispose");
end