Lua_WelcomeWindow = class("Lua_WelcomeWindow", Lua_Window);
function Lua_WelcomeWindow:ctor()
	self:superCall("ctor");

	self.windowName = "Lua_WelcomeWindow";
	self.skinName = "WelcomeWindow_skin";
	self.showClose = false;
end

function Lua_WelcomeWindow:buildShowItem()
	self:superCall("buildShowItem");

	self.tipObj:SetActive(false);
	self.skipObj:SetActive(false);

	local videoStr = "/video/welcomeVideo_" .. DataCenter.roleData.career .. ".mp4"
	self.videoImage = UICreate.createVideoImage(self.content, videoStr, 0, 0, 1560, 720);
	self.videoImage.isLooping = false;
	self.videoImage.playOnAwake = false;
	self.videoImage:setDepth(5);
	self.videoImage:addVideoEndFun(self, self.playEnd);

	self:addLuaEvent("PLAY_WELCOME_VIDEO", self, self.playStart);
end

function Lua_WelcomeWindow:playStart()
	if self.videoImage == nil then
		self:hide();
		return;
	end

	self.videoImage:play();
	local skipTime = Lua_CommonUtil.getCommonConfig("first_skip_time", 1);
	Lua_CommonUtil.delayCall(skipTime, self, self.showSkipBtn);

	AudioManager.muteAllMusic();
end

function Lua_WelcomeWindow:showSkipBtn()
	Lua_CommonUtil.removeTimer(self, self.showSkipBtn);

	self.skipObj:SetActive(true);
	self.skipBtn:addClickFuntion(self, self.onSkipBtnClick);
end

function Lua_WelcomeWindow:onSkipBtnClick()
	self:playEnd(true);
end

function Lua_WelcomeWindow:playEnd(val)
	self.videoImage:setEnable(false);
	self.skipObj:SetActive(false);

	self.tipObj:SetActive(true);
	self:showReward();

	if self.isRecover == nil then
		self.isRecover = true
		AudioManager.playAllMusic();
	end
end

function Lua_WelcomeWindow:showReward()
	self.autoTime = Lua_CommonUtil.getCommonConfig("guide_auto_time", 1);
	self.tipsLab.text = LanUtil.getValue(107498) .. "(" .. tostring(self.autoTime) .. "s)";

	self:addTimer("countDown", 1, self, self.countDown);
	self.sureBtn:addClickFuntion(self, self.onOkClick);
end

function Lua_WelcomeWindow:onOkClick(go)
	self:hide();
	DataCenter.taskData:execTruckTask();
end

function Lua_WelcomeWindow:countDown()
	self.autoTime = self.autoTime - 1;
	if self.autoTime <= 0 then
		Lua_CommonUtil.removeTimer(self, self.countDown);
		self:onOkClick();
		return;
	else
		self.tipsLab.text = LanUtil.getValue(107498) .. "(" .. tostring(self.autoTime) .. "s)";
	end
end

function Lua_WelcomeWindow:dispose()
	Lua_CommonUtil.removeTimer(self, self.showSkipBtn);
	Lua_CommonUtil.removeTimer(self, self.onSkipBtnClick);
	Lua_CommonUtil.removeTimer(self, self.countDown);
	if self.isRecover == nil then
		self.isRecover = true
		AudioManager.playAllMusic();
	end

	if self.videoImage ~= nil then
		self.videoImage:dispose();
		self.videoImage = nil;
	end
	
	self:superCall("dispose");
end